@@ -8,6 +8,7 @@ pub mod code_gen;
 pub mod constants;
 pub mod errors;
 pub mod json_abi;
+pub mod parameters;
 pub mod rustfmt;
 pub mod source;
 pub mod types;
@@ -28,6 +29,9 @@ pub enum ParamType {
     Bool,
     Byte,
     B256,
+    // The Unit paramtype is used for unit variants in Enums. The corresponding type field is `()`,
+    // similar to Rust.
+    Unit,
     Array(Box<ParamType>, usize),
     #[strum(serialize = "str")]
     String(usize),
@@ -55,7 +59,9 @@ impl ParamType {
     // see https://github.com/FuelLabs/sway/issues/1368.
     pub fn get_return_location(&self) -> ReturnLocation {
         match &*self {
-            Self::U8 | Self::U16 | Self::U32 | Self::U64 | Self::Bool => ReturnLocation::Return,
+            Self::Unit | Self::U8 | Self::U16 | Self::U32 | Self::U64 | Self::Bool => {
+                ReturnLocation::Return
+            }
 
             _ => ReturnLocation::ReturnData,
         }
@@ -95,6 +101,7 @@ impl fmt::Display for ParamType {
                 let s = format!("Tuple(vec![{}])", inner_strings.join(","));
                 write!(f, "{}", s)
             }
+            ParamType::Unit => write! {f, "Unit"},
             _ => {
                 write!(f, "{:?}", self)
             }
@@ -106,6 +113,9 @@ impl fmt::Display for ParamType {
 #[derive(Debug, Clone, PartialEq, EnumString)]
 #[strum(ascii_case_insensitive)]
 pub enum Token {
+    // Used for unit type variants in Enum. An "empty" enum is not represented as Enum<empty box>,
+    // because this way we can have both unit and non-unit type variants.
+    Unit,
     U8(u8),
     U16(u16),
     U32(u32),
